import 'package:flutter/material.dart';
import 'package:flutter_curiosity/flutter_curiosity.dart';

class ScannerBox extends StatefulWidget {
  final Widget child;
  final Color borderColor;
  final Color scannerColor;
  final Size size;
  final double hornStrokeWidth;
  final double scannerStrokeWidth;

  ScannerBox(
      {Key key,
      this.child,
      Color borderColor,
      Color scannerColor,
      this.size,
      this.hornStrokeWidth,
      this.scannerStrokeWidth})
      : this.borderColor = borderColor ?? Colors.white,
        this.scannerColor = scannerColor ?? Colors.white,
        super(key: key);

  @override
  ScannerBoxState createState() => ScannerBoxState();
}

class ScannerBoxState extends State<ScannerBox> with TickerProviderStateMixin {
  AnimationController controller;

  @override
  void initState() {
    super.initState();
    controller = AnimationController(
        vsync: this, duration: Duration(milliseconds: 1000));
    controller.repeat(reverse: true);
  }

  @override
  void dispose() {
    controller.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
        animation: controller,
        builder: (BuildContext context, Widget child) => CustomPaint(
              foregroundPainter: ScannerPainter(
                  scannerStrokeWidth: widget.scannerStrokeWidth,
                  hornStrokeWidth: widget.hornStrokeWidth,
                  value: controller.value,
                  size: widget.size,
                  borderColor: widget.borderColor,
                  scannerColor: widget.scannerColor),
              child: widget.child,
              willChange: true,
            ));
  }
}
